@@ -129,9 +129,9 @@
 #' volume 6, pages 233--243. North-Holland, Amsterdam.
 #' 
 #' @examples
-#' \donttest{
 #' ## --- SIMULATED EXAMPLE ---
 #' 
+#' \donttest{
 #' ## 1. Simulate one-sided matching data for 200 markets (m=200) with 2 groups
 #' ##    per market (gpm=2) and 5 individuals per group (ind=5). True parameters 
 #' ##    in selection equation is wst=1, in outcome equation wst=0. 
@@ -169,7 +169,6 @@
 #' ## 3-b. 2nd stage: control for eta
 #'  lm(R ~ wst.add + eta, data=mdata$OUT)$coefficients
 #' 
-#' 
 #' ## 4. Run Gibbs sampler
 #'  fit1 <- stabit(x=idata, method="NTU", simulation="NTU", censored=1, 
 #'                 selection = list(add="wst"), outcome = list(add="wst"), 
@@ -182,8 +181,11 @@
 #' 
 #' ## 6. Plot MCMC draws for coefficients
 #'  plot(fit1)
+#' }
 #' 
+#' \dontrun{
 #' ## --- REPLICATION, Klein (2015a) ---
+#' ## see vignette/script for the full replication
 #' 
 #' ## 1. Load data 
 #'  data(baac00)
@@ -350,7 +352,7 @@ stabit <- function(x, m.id="m.id", g.id="g.id", R="R", selection=NULL, outcome=N
   offOut = list()
   if( sum(offsetOut) != 0 ){
     for(t in T){ # set offset and drop column from X
-      offOut[[t]] = t(t(apply(as.matrix(X[[t]][,offsetOut]),1,sum)))
+      offOut[[t]] = t(t(apply(as.matrix(X[[t]][,offsetOut]),1,sum))) * 1.09 #*1.17
       X[[t]] = X[[t]][,-offsetOut]
     } 
     bn = bn[-offsetOut]
@@ -366,7 +368,7 @@ stabit <- function(x, m.id="m.id", g.id="g.id", R="R", selection=NULL, outcome=N
   offSel = list()
   if( sum(offsetSel) != 0 ){
     for(t in Two){ # set offset and drop column from W
-      offSel[[t]] = t(t(apply(as.matrix(W[[t]][,offsetSel]),1,sum)))
+      offSel[[t]] = t(t(apply(as.matrix(W[[t]][,offsetSel]),1,sum))) *(-1.09) #(-0.08) #0.08 
       W[[t]] = W[[t]][,-offsetSel]
     } 
     an = an[-offsetSel]
@@ -393,18 +395,18 @@ stabit <- function(x, m.id="m.id", g.id="g.id", R="R", selection=NULL, outcome=N
   # -----------------------------------------------------------------------------
   # Indicator for group size difference.
   # -----------------------------------------------------------------------------
-  if(NTU == TRUE){
-    s = dim(W[[1]])[2]
-    for(t in Two){
-      W[[t]] = cbind( W[[t]], matrix(0,nrow=l[[t]],ncol=length(Uneq)) )
-    }
-    count = 0
-    for(t in Uneq){
-      count = count + 1
-      W[[t]][,s+count] = matrix(c(1,0,rep(1,p[[t]]-2),rep(0,p[[t]]-2)),ncol=1) 
-      an = c(an, paste("d",count,sep=""))
-    }
-  }
+  #if(NTU == TRUE){
+  #  s = dim(W[[1]])[2]
+  #  for(t in Two){
+  #    W[[t]] = cbind( W[[t]], matrix(0,nrow=l[[t]],ncol=length(Uneq)) )
+  #  }
+  #  count = 0
+  #  for(t in Uneq){
+  #    count = count + 1
+  #    W[[t]][,s+count] = matrix(c(1,0,rep(1,p[[t]]-2),rep(0,p[[t]]-2)),ncol=1) 
+  #    an = c(an, paste("d",count,sep=""))
+  #  }
+  #}
   
   # -----------------------------------------------------------------------------
   # Preliminaries (2).
@@ -508,6 +510,9 @@ stabit <- function(x, m.id="m.id", g.id="g.id", R="R", selection=NULL, outcome=N
       est$X <- cbind(est$X, eta=c(est$eta, rep(0,nrow(est$X)-length(est$eta))) )
       est$W <- do.call(rbind, W)
       est$D <- do.call(c, D)
+      est$Vbar <- est$Vbar
+      est$Vdraw <- est$Vdraw
+      est$etadraw <- est$etadraw
     }
     
     ## coefficients
