@@ -41,7 +41,7 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
   // Outcome variables.
   // ---------------------------------------------
   
-  arma::field<arma::colvec> R(T), offOut(T), Y(T);
+  arma::field<arma::colvec> R(T), offOut(T), Y(T); 
   for(int i=0; i<T; i++){
     R(i)      = Rcpp::as<arma::colvec>(Rr[i]);      // dependent variable
     offOut(i) = Rcpp::as<arma::colvec>(offOutr[i]); // offset
@@ -52,9 +52,14 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
     }
   }
   
-  arma::field<arma::colvec> V(TwoN), offSel(TwoN);
+  arma::field<arma::colvec> V(TwoN), Vbar(TwoN), Vdraw(TwoN), offSel(TwoN), etadraw(T);
   for(int i=Two1; i<TwoN; i++){
     V(i) = arma::zeros(W(i).n_rows,1);              // latent match valuation
+    
+    Vbar(i) = arma::zeros(W(i).n_rows,1);           // Vupperbar and Vlowerbar
+    Vdraw(i) = arma::zeros(W(i).n_rows,1);          // last iteration's draw of V
+    etadraw(i) = arma::zeros(W(i).n_rows,1);        // last iteration's draw of eta
+    
     offSel(i) = Rcpp::as<arma::colvec>(offSelr[i]); // offset
   }
   
@@ -202,20 +207,23 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
       if(ntu==TRUE){ // non-transferable utility
         for(int t=Two1; t < TwoN; t++){
           // considering _upper_bounds_ for all unobserved groups in market t.
-          Vupperbar = arma::max( V(t).rows(0,1) ); // max valuation of observed groups as upper bound
+          Vupperbar = arma::max( V(t).rows(0,1) + offSel(t).rows(0,1) ); // max valuation of observed groups as upper bound
           for(int G=2; G < l(t); G++){
             Vhat    = arma::as_scalar( W(t).row(G)*alpha );
-            V(t)(G) = truncn(Vupperbar, FALSE, Vhat, 1.0); // bound, lb, mu, sigma
+            V(t)(G) = truncn(Vupperbar - offSel(t)(G), FALSE, Vhat, 1.0); // bound, lb, mu, sigma
+            Vbar(t)(G) = Vupperbar;
           }
         
           // considering _lower_bounds_ for observed groups in market t.
           for(int G=0; G < 2; G++){ // observed groups A and B.
-            Vlowerbar = arma::max( V(t).rows(2,l(t)-1) ); // max valuation of unobserved groups as lower bound
+            Vlowerbar = arma::max( V(t).rows(2,l(t)-1) + offSel(t).rows(2,l(t)-1) ); // max valuation of unobserved groups as lower bound
             Vhat = arma::as_scalar( W(t).row(G)*alpha + ((Y(t)(G) - X(t).row(G)*beta)*delta)/(sigmasquarexi + pow(delta,2)) );
-            if(V(t)(1-G) > Vlowerbar){ // no bounds if valuation of other observed group exceeds that of all unobserved groups.
+            if(V(t)(1-G) + offSel(t)(1-G) > Vlowerbar){ // no bounds if valuation of other observed group exceeds that of all unobserved groups.
               V(t)(G) = ::Rf_rnorm(Vhat, sqrt(sigmasquarexi/(sigmasquarexi+pow(delta,2))) );
+              Vbar(t)(G) = -1*arma::datum::inf;
             } else{
-              V(t)(G) = truncn(Vlowerbar, TRUE, Vhat, sqrt(sigmasquarexi/(sigmasquarexi+pow(delta,2))) ); // bound, lb, mu, sigma
+              V(t)(G) = truncn(Vlowerbar - offSel(t)(G), TRUE, Vhat, sqrt(sigmasquarexi/(sigmasquarexi+pow(delta,2))) ); // bound, lb, mu, sigma
+              Vbar(t)(G) = Vlowerbar;
             }
           }
         }
@@ -231,12 +239,14 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
             Vupperbar = eqsum - ( V(t)(P(t)(G)-1) + offSel(t)(P(t)(G)-1) ) - offSel(t)(G);
             Vhat = arma::as_scalar( W(t).row(G)*alpha );
             V(t)(G) = truncn(Vupperbar, FALSE, Vhat, 1.0); // bound, lb, mu, sigma
+            Vbar(t)(G) = Vupperbar;
           }
           // ...then for "other" groups because of interdependence between their valuations
           for(int G=p(t); G<l(t); G++){ // p(t) gives index of first "other" group
             Vupperbar = eqsum - ( V(t)(P(t)(G)-1) + offSel(t)(P(t)(G)-1) ) - offSel(t)(G);
             Vhat = arma::as_scalar( W(t).row(G)*alpha );
             V(t)(G) = truncn(Vupperbar, FALSE, Vhat, 1.0); // bound, lb, mu, sigma
+            Vbar(t)(G) = Vupperbar;
           }
           
           // considering _lower_bounds_ for observed groups in market t.
@@ -245,6 +255,7 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
             Vlowerbar = neqmaxsum - ( V(t)(1-G) + offSel(t)(1-G) ) - offSel(t)(G);            
             Vhat = arma::as_scalar( W(t).row(G)*alpha + ( (Y(t)(G) - X(t).row(G)*beta )*delta ) / (sigmasquarexi + pow(delta,2)) );
             V(t)(G) = truncn(Vlowerbar, TRUE, Vhat, sqrt(sigmasquarexi/(sigmasquarexi+pow(delta,2))) ); // bound, lb, mu, sigma
+            Vbar(t)(G) = Vlowerbar;
           }  
         }
       } 
@@ -355,6 +366,17 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
       sigmasquarexi = 1/sigmasquarexiinverse;
     }
     
+    if(iter == niter-1){ // save last itertion's draw of latents and error terms
+      if(selection == TRUE){ 
+        if(ntu==TRUE){ // non-transferable utility
+          for(int t = Two1; t < TwoN; t++){
+            Vdraw(t) = V(t);
+            etadraw(t) = V(t) - W(t)*alpha;
+          }
+        }
+      }
+    }
+    
     // ---------------------------------------------  
     // save this iterations draws.
     // ---------------------------------------------
@@ -378,7 +400,10 @@ List stabitSel2(Rcpp::List Xr, Rcpp::List Rr, Rcpp::List Wr,
       Named("betadraws") = alphadraws,
       Named("alphadraws") = betadraws,
       Named("deltadraws") = deltadraws,
-      Named("etadraws") = etadraws
+      Named("etadraws") = etadraws,
+      Named("Vbar") = Vbar,
+      Named("Vdraw") = Vdraw,
+      Named("etadraw") = etadraw
     );  
   } else if((binary==TRUE) & (selection==FALSE)){
     return List::create(  
